ATTENTION, SI VOUS MODIFIEZ CE POINT, CERTAINES BALISES PEUVENT DISPARAITRE EN FONCTION DE LA CONFIGURATION DE CKEDITOR (PS: ce texte utilise la class CSS "highlight-red")

Idéalement utiliser un modèle dont le style par défaut a été redéfini, ceci permet de tester qu'un paragraphe utilisant un style est rendu avec le même style (Police et taille de police) qu'un paragraphe sans style

Pour tester l'utilisation du style "Signature" il faut également le redéfinir dans le modèle et lui adjoindre par exemple une couleur de fond

>>>>> TEXTE <<<<< :

Du texte avec du gras, de l'italique, du souligné, du barré, du gras souligné :

Un paragraphe utilisant un style ou n'en utilisant pas est rendu avec la même police/taille de police :

Du texte n'utilisant aucun style...

Du texte utilisant un style ajoutant un décalage margin-left:25px...

Utilisation des tags pour la mise en forme :

- italique barré;
- italique gras;
- italique souligné;
- gras barré;
- gras souligné, NE FONCTIONNE PAS AVEC LIBREOFFICE4 EN WORD, TESTER EN LIBREOFFICE5;
- gras souligné;
- gras italique barré;
- gras italique souligné;
- gras barré souligné;
- gras italique barré souligné.

sans liste :

italique barré;

italique gras;

italique souligné;

gras barré;

gras souligné, NE FONCTIONNE PAS AVEC LIBREOFFICE4 EN WORD, TESTER EN LIBREOFFICE5;

gras souligné;

gras italique barré;

gras italique souligné;

gras barré souligné;

gras italique barré souligné.

Styles qui ne se finissent pas en même temps :

test test test test test

test test test test test

Utilisation de CSS pour la mise en forme :

style directement sur <li style=...>

- italique barré;
- italique gras;
- italique souligné;
- gras barré;
- gras souligné;
- gras italique barré;
- gras italique souligné;
- gras barré souligné;
- gras italique barré souligné;
- utilisation de 'text-decoration: none'.

sans liste :

italique barré;

italique gras;

italique souligné;

gras barré;

gras souligné;

gras italique barré;

gras italique souligné;

gras barré souligné;

gras italique barré souligné;

utilisation de 'text-decoration: none'.

style sur <p> dans <li>

- italique barré;

- italique gras;

- italique souligné;

- gras barré;

- gras souligné;

- gras italique barré;

- gras italique souligné;

- gras barré souligné;

- gras italique barré souligné.

style sur <span> dans <li>

- italique barré;
- italique gras;
- italique souligné;
- gras barré;
- gras souligné;
- gras italique barré;
- gras italique souligné;
- gras barré souligné;
- gras italique barré souligné.

Style défini sur un p contenu dans un li est transféré sur le li et gardé :

- attribut "style" italique gras;

- attribut "class" utilisant "Signature", un style par défaut de LibreOffice.

Style font-size en px, pt, % et nommé (small, x-small, large, ...) :

5px : text text text text text text text

10px : text text text text text text text

15px : text text text text text text text

5pt : text text text text text text text

10pt : text text text text text text text

15pt : text text text text text text text

85% : text text text text text text text

100% : text text text text text text text

115% : text text text text text text text

small : text text text text text text text

large : text text text text text text text

x-large : text text text text text text text

Texte avec espace entre chaque paragraphe :

Texte texte texte...

Texte texte texte...

Texte texte texte...

Texte texte texte...

Retrait en début de ligne :

Mon texte sans retrait

Mon texte avec retrait Mon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retraitMon texte avec retrait

Mon texte utilisant text-indent, seule la première ligne du paragraphe est impactée par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait,par le retrait

Alignement du texte :

Paragraphe sans alignement

Paragraphe aligné à gauche

Paragraphe aligné à droite

Paragraphe centré

Long paragraphe justifié Long paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifiéLong paragraphe justifié

Alignement du texte, utilisation des valeurs start/end plante dans appy <= 0.9.8 :

Utilisation de text-align:start;

Utilisation de text-align:end;

Bloc de texte gardé sur la même page (utilise le style "ParaKWN" défini par défaut dans une Pod template) :

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Ce bloc de texte ne sera pas coupé à l'impression (ajouter saut de ligne au dessus de ce texte dans le document généré pour vérifier)

Retrait en début de ligne négatif :

Mon texte avec retrait de margin-left:-1cm;

Mon texte avec retrait de margin-left:-.75pt;

Mon texte sans retrait.

Texte avec nombreux espaces avant :

Mon texte

Aligné manuellement

>>>>> TITRES (Titre1, Titre2, ...) <<<<< :

# Titre1 Titre1 Titre1

## Titre2 Titre2 Titre2

### Titre3 Titre3 Titre3

#### Titre4 Titre4 Titre4

##### Titre5 Titre5 Titre5

###### Titre6 Titre6 Titre6

>>>>> PUCES CLASSIQUES <<<<< :

- puce normale;

- puce contenue dans un <p>;

- puce barrée contenue dans un <p>;

  - sous-puce;

  - sous-puce soulignée;

  - sous-puce barrée;

    - sous-sous-puce gras;

    - sous-sous-puce;

- les puces avec formattage sont testées ci-dessus;

>>>>> PUCES NUMEROTEES <<<<< :

Numérotation classique :

1. Texte texte gras;
2. Texte texte souligné;
3. Texte gras/italique/souligné/barré texte;
4. Texte texte texte;
5. Texte texte texte;

Avec sous-numérotation :

1. Texte texte texte;
2. Texte italique texte;
   1. Texte souligné;

   2. Texte gras texte dans un <p>;

   3. Texte texte texte dans un <p> et barré;

3. Texte texte texte;

1. Texte souligné;

2. Texte gras texte dans un <p>;

3. Texte texte texte dans un <p> et barré;

4. Texte texte texte;

1. Texte souligné;

2. Texte gras texte dans un <p>;

3. Texte texte texte dans un <p> et barré;

5. Texte texte texte;

Numérotation chiffres et lettres :

1. Texte gras barré;
2. Texte texte text;
   1. sous-puce lettre minuscule, Texte texte text;
   2. Texte texte text;
   3. Texte texte text;
3. Texte texte text;
4. Texte texte text;
   1. sous-puce lettre MAJUSCULE utilisant un "b" au lieu d'un "strong" pour le gras, Texte texte text;
   2. Texte texte text;
5. Texte texte text;

Listes numérotées imbriquées sans valeur pour <li> non rendu en appy.pod <=0.9.8:

1. 1. 1. Sous-liste imbriquée 1, 2 niveaux de liste "ol" au-dessus

1. 1. 1. Sous-liste imbriquée 1, 2 niveaux de liste "ol" au-dessus utilisant list-style-type:none

- - - Sous-liste imbriquée 1, 2 niveaux de liste "ul" au-dessus

- - - Sous-liste imbriquée 1, 2 niveaux de liste "ul" au-dessus utilisant list-style-type:none

Renumérotation :

1. Texte texte text;
2. Texte texte text;
3. Texte texte text;

Du texte inséré dans la liste (avec un margin-left sur le <p>) puis...

4. On recommence à 4;
5. Texte texte text;
   1. Texte texte texte;
   2. Texte texte texte;
   3. Texte texte texte;
6. Texte texte text;

Puces numérotées et classiques :

1. Texte texte texte;
2. Texte texte texte;
   - Texte texte texte;
   - Texte texte texte;
3. Texte texte texte;
4. Texte texte texte;

Puces contenant structure complexe :

- Texte contenu dans un li/div/p

- Texte contenu dans un li/p/u/b

- Texte contenu dans un li/div/p

Puces utilisant du margin-left pour gérer le décalage :

Nous testons la numérotations des points et ss-point:

1. 1er point

para du 1ier point

2. 2ième point

para du 2ier point

1. 1ier ss-point

para du 1ier ss-point

2. 2ième ss-point

para du 2ième ss-point

3. 3ième point

   1. 1er ss-point

para du 1ier ss-point

- 1ier sss-point

para du sss-point

- 2ième sss-point

para du sss-point

- 3ième sss-point

para du sss-point

2. 2ième ss-point

para du 2ième ss-point

4. 4ième point

para du 1ier point

5. 5ième point

para du 1ier point

>>>>>>>>>>>>>>> TABLEAUX <<<<<<<<<<<<<<< :

Les tableaux >= 500px sont affichés en 100% dans le document produit.

Tableau de 250px :

1 | Texte texte texte texte texte texte texte texte gras barré texte texte texte texte texte texte
2 | Texte texte texte texte texte texte texte gras italique texte texte texte texte texte texte texte
3 | Texte texte texte texte texte texte texte italique gras barré texte texte texte texte texte texte

Bordure tableau via style sur balise table + border="1", ne rendait pas la bordure dans appy 0.9.7 :

1 | Texte texte texte texte texte texte texte texte gras barré texte texte texte texte texte texte
2 | Texte texte texte texte texte texte texte gras italique texte texte texte texte texte texte texte
3 | Texte texte texte texte texte texte texte italique gras barré texte texte texte texte texte texte

Texte collé à la bordure lorsque cellspacing ou cellpadding utilsé dans appy.pod 0.9.7 :

Sans cellspacing/cellpadding

1 | Texte texte texte texte texte texte texte texte gras barré texte texte texte texte texte texte
2 | Texte texte texte texte texte texte texte gras italique texte texte texte texte texte texte texte
3 | Texte texte texte texte texte texte texte italique gras barré texte texte texte texte texte texte

Avec cellspacing/cellpadding à "1"

1 | Texte texte texte texte texte texte texte texte gras barré texte texte texte texte texte texte
2 | Texte texte texte texte texte texte texte gras italique texte texte texte texte texte texte texte
3 | Texte texte texte texte texte texte texte italique gras barré texte texte texte texte texte texte

Avec cellspacing/cellpadding à "0"

1 | Texte texte texte texte texte texte texte texte gras barré texte texte texte texte texte texte
2 | Texte texte texte texte texte texte texte gras italique texte texte texte texte texte texte texte
3 | Texte texte texte texte texte texte texte italique gras barré texte texte texte texte texte texte

Bordure définie sur <td> utilisant 1px, plante appy.pod <= 0.9.8 :

1

Largeur de tableau définie à 0px, tableau rendu sans largeur appy.pod <= 0.9.8 :

Attribut "width" :

1 | 2 | 3

Attribut "style:width=0px;" :

1 | 2 | 3

Désactivation de l'optimisation de la largeur des colonnes lors de l'utilisation du style "table-layout: fixed" :

Tableau avec largeur fixée à 150px mais qui va être optimisé :

1 | 2 | 3

Tableau sans aucun style (ni largeur) :

1 | 2 | 3

Tableau "fixed" avec largeur définie à 150px :

1 | 2 | 3

Tableau "fixed" sans largeur définie :

1 | 2 | 3

Tableau complexe de 17cm de large :

Couleur de fond en rgb(), en #123123 et en HTML color.

TEXTE CENTRE ET GRAS
Né(e) le : ..., Etat civil : ...
CENTRE, GRAS ET SOULIGNE

Utilisation de "colspan" |
Couleur de fond RGB, text centré, utilisation de "rowspan" | Souligné | DUREE PAR GROUPE | Coef- ficient | VALORISATION BAREMIQUE
Couleur fond hexa | Couleur fond HTML color | du | au | ANS | MOIS |  | ANS | MOIS
|  |  |  |  |  | TOTAL: |  |
Texte... |  |
Augmentation les ... |  |

Tableau avec nombreuses colonnes, taille de texte réduite en utilisant "font-size: 9px" et "font-size: 8px", cellspacing="0", headers du tableau en gras en utilisant "font-weight: bold" :

Température | Janvier | Février | Mars | Avril | Mai | Juin | Juillet | Août | Septembre | Octobre | Novembre | Décembre
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Les cinq mois les plus chauds | 1975 | 6.3 | 1990 | 7.9 | 1991 | 9.5 | 1987 | 11.9 | 1947 | 15.8 | 1976 | 19.3 | 1994 | 21.8 | 1997 | 21.2 | 1949 | 17.7 | 1921 | 14.0 | 1994 | 10.4 | 1934 | 7.5
1921 | 6.2 | 1926 | 7.6 | 1957 | 9.5 | 1993 | 11.8 | 1989 | 15.8 | 1950 | 18.1 | 1983 | 21.2 | 1911 | 20.9 | 1999 | 17.7 | 1995 | 13.7 | 1984 | 9.4 | 1974 | 7.0
1988 | 6.2 | 1961 | 7.2 | 1989 | 9.1 | 1961 | 11.7 | 1992 | 15.7 | 1970 | 17.9 | 1995 | 20.9 | 1995 | 20.4 | 1961 | 17.3 | 1989 | 12.7 | 1938 | 9.0 | 1988 | 6.9
1916 | 6.1 | 1995 | 6.8 | 1981 | 9.1 | 1952 | 11.5 | 1998 | 15.6 | 1947 | 17.8 | 1976 | 20.0 | 1947 | 20.4 | 1947 | 17.0 | 1990 | 12.6 | 1963 | 8.8 | 1915 | 6.3
1983 | 5.9 | 1966 | 6.6 | 1990 | 8.7 | 1949 | 11.2 | 1917 | 15.5 | 1986 | 17.5 | 1999 | 19.7 | 1990 | 19.7 | 1982 | 16.9 | 1969 | 12.6 | 1913 | 8.7 | 1918 | 6.3
normales |  | 2.5 |  | 3.0 |  | 5.9 |  | 8.7 |  | 12.8 |  | 15.3 |  | 17.0 |  | 16.9 |  | 14.4 |  | 10.3 |  | 5.8 |  | 3.3
Les cinq mois les plus froids | 1985 | -2.8 | 1947 | -3.2 | 1971 | 3.2 | 1908 | 6.2 | 1984 | 10.4 | 1991 | 13.2 | 1965 | 14.4 | 1941 | 15.0 | 1986 | 11.7 | 1992 | 7.8 | 1993 | 2.8 | 1963 | -0.5
1987 | -2.8 | 1986 | -3.2 | 1987 | 3.1 | 1970 | 6.2 | 1991 | 10.4 | 1909 | 13.1 | 1913 | 14.3 | 1956 | 14.4 | 1931 | 11.6 | 1919 | 7.1 | 1915 | 2.7 | 1969 | -0.5
1942 | -3.6 | 1942 | -3.5 | 1955 | 2.7 | 1929 | 6.0 | 1962 | 10.2 | 1956 | 12.6 | 1909 | 14.2 | 1920 | 14.3 | 1925 | 11.5 | 1974 | 6.8 | 1925 | 2.7 | 1927 | -0.6
1940 | -4.2 | 1929 | -3.6 | 1962 | 2.7 | 1903 | 5.3 | 1941 | 9.8 | 1916 | 12.2 | 1907 | 13.6 | 1924 | 14.2 | 1952 | 11.2 | 1922 | 6.5 | 1919 | 2.5 | 1950 | -1.2
1963 | -4.6 | 1956 | -6.1 | 1917 | 2.5 | 1917 | 4.6 | 1902 | 8.5 | 1923 | 11.5 | 1919 | 13.5 | 1912 | 13.8 | 1912 | 10.7 | 1905 | 5.9 | 1921 | 1.8 | 1933 | -2.7

Tableau avec gras défini sur première ligne, vérifier que les lignes 2 et 3 ne sont pas en gras (problème génération Word Ooo4).

1 | Texte texte texte texte texte texte texte texte
2 | Texte sans gras sans gras
3 | Texte sans gras sans gras

Tableau avec largeur fixée à 1000px et 4ème cellule fixée à 200px, mal rendu dans Oo5 :

Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
--- | --- | --- | --- | ---
lignes de textes dans des <p> différents, saut de ligne gardé seconde ligne dans un <p> troisième ligne dans un <p> | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text

Tableau avec alignement vertical et horizontal :

Texte vertical haut | Texte centré texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte
Texte bas | Texte à droite texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte
Texte centré | Texte justifié texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte
Texte aligné à droite, style appliqué sur un p dans le td | Texte centré, style appliqué sur un p dans le td
Comportement par défaut | Texte par défaut texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte texte

Tableau une seule colonne avec couleurs de fond et couleur de texte :

Fond en RVB et texte vert
Dans un <p> fond en # et texte bleu, le <p> étant supprimé, le style color n'est pas gardé et le texte rendu n'est pas bleu
Dans un <span> fond en # et texte bleu, le <span> est gardé mais les styles pas...
Dans un <td> fond en # et texte bleu, les styles définis sur le <td> sont gardés
Fond en HTML color et texte gris

Tableau une seule colonne utilisé comme titre :

A. Description de la fonction

Tableau sans colonne de 1024px de large (non rendu) :

Tableau sans bordures (border="0" ou style="border: none;") :

border="0"

Texte 1.1; | Texte 1.2; | Texte 1.3;
Texte 2.1; | Texte 2.2; | Texte 2.3;

border="1" style="width:500px; border: none;"

Texte 1.1; | Texte 1.2; | Texte 1.3;
Texte 2.1; | Texte 2.2; | Texte 2.3;

Tableau structure complexe table/td/div/p :

Texte contenu dans un td/div/p

Tableau utilisant des colspan sur la première ligne "inutilement" :

Texte | Texte

Tableau style défini sur un p contenu dans un td est transféré sur le td et gardé :

Texte utilisant attribut "style" gras; | Texte utilisant attribut "class" la classe par défaut "Signature".

Tableau dont la largeur des colonnes est fixée mais dont le résultat n'est pas satisfaisant par rapport à la preview HTML. L'utilisation de la fonctionnalité de LibreOffice "largeur optimale" des colonnes pourrait gérer cela... De plus vérifier que le texte de la première colonne est bien sur plusieurs lignes, pas une seule ligne avec textes séparés par des espaces :

FP intercommunale | TOTAL | Développment Rural | Autres pouvoirs subsidiants | Mobilité - Tralala | Commune
--- | --- | --- | --- | --- | ---
ViciGal, création d'une voie verte au coeur du Condroz namurois | (TFC) | Taux | Intervention | Taux | Intervention | Taux | Intervention | Taux | Intervention
Acquisitions Partie DR à 90,00% : | 18.480,00 | 90% | 16.632,00 | 0% | 0,00 | 0% | 0,00 | 10% | 1.848,00
Partie DR + CGT + Mobilité (Tralala) | 520.882,00 | 50% | 260.441,00 | 9% | 49.448,00 | 22% | 116.682,00 | 18% | 93.311,00
Financement DGO1 | 28.512,00 | 0% | 0,00 | 100% | 28.512,00 | 0% | 0,00 | 0% | 0,00
Honoraires et frais Partie DR : | 111.378,00 | 50% | 55.689,00 | 0% | 0,00 | 0% | 0,00 | 50% | 55.689,00
Partie DGO1 | 3.168,00 | 0% | 0,00 | 100% | 3.168,00 | 0% | 0,00 | 0% | 0,00
Total EURO (TFC) | 1.111111,00 |  | 677.555,00 |  | 169.703,00 |  | 116.682,00 |  | 200.000,00

Tableau 5 colonnes de 1000px de large dont seule la colonne 4 a une taille définie à 200px (notamment mal rendu dans Oo5) :

Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
--- | --- | --- | --- | ---
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text
Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text | Text Text Text Text Text Text Text Text Text Text

Cas concret :

Montant de commande |  | € 111.111,20
Montant des avenants |  | € 1.234,56
Montant de commande après avenants |  | € 123.456,78
TVA | + | € 12.345,67
TOTAL | = | € 123.456,78
Montant des états d’avancement précédents |  | € 123.456,78
Révisions des prix | + | € -1.234,56
Total HTVA | = | € 132.456,78
TVA | + | € 12.345,67
TOTAL | = | € 123.456,78
État d’avancement actuel |  | € 1.234,56
Révisions des prix | + | € -12,34
Total HTVA | = | € 1.234,56
TVA | + | € 1.234,56
TOTAL | = | € 1.234,56
Montant total des travaux exécutés |  | € 132.456,78
Révisions des prix | + | € -1.234,56
Total HTVA | = | € 123.456,78
TVA | + | € 12.345,67
TOTAL | = | € 123.456,78

Cas concret 2 :

2016
N° | Article budgétaire | Fournisseur | Libellé | Montant Estimatif
1305 | 104/741-51 20160003 Hôtel de Ville –mobilier de bureau | Ets AAA | 10 sièges visiteurs | 2.190,10
1321 | 104/724-60 20160002 Maintenance bâtiments administratifs | Parc du Tapis | Achat et pose d’un vinyle Bon en urgence avec accord de Monsieur AAA | 2.704,94
1322 | 421/125-06 Prestations de tiers pour les bâtiments du AAA | Ets AAA | Réparation d’une porte sectionnelle au garage AAA | 1.424,17
1323 | 72204/123-19 Frais d’achats de manuels scolaires pour l’école de AAA | Librairie AAA | Manuels agréés Bon en urgence avec accord de Monsieur AAA | 345,25
1324 | 8401/124-02 Fournitures techniques PCS | Ets AAA | Achats de pichets | 137,94
1325 | 72205/123-19 Achat de livres pour bibliothèque | Ed. De AAA | Achat de livres | 106,10
1326 | annulé |  |  |
1327 | 105/123-16 Frais de réception | Boucherie AAA | Collège du 17/10/2016 Sandwiches pour le mérite culturel et sportif du 18/11/2016 | 159,00
1328 | 763/124-02 Frais de fêtes et cérémonies publiques | Fleurs Christine – AAA | Collège du 17 octobre 2016 17 Gerbes de fleurs pour les 11 et 13 novembre 2016 | 595,00
1329 | 124/124-05 Vêtements de travail pour le personnel d’entretien | Sprl AAA Co | Sabots pour travaux de nettoyage | 266,79
1330 | 124/125-02 Achats pour entretien des divers bâtiments communaux | AAA | Lampe au Châlet de AAA | 16,53
1331 | 421/123-16 Frais de réception et de réprésentation du AAA | Café AAA | Fournitures pour machine à café | 261,87
1332 | 421/124-02 Achat de petite matériel et outillage de voirie | AAA Belux | Peinture en bombe | 65,48
1333 | 421/125-02 Achats pour entretien des bâtiments du AAA | ABCDEF | Fiche transfo pour chauffage | 21,01
1334 | 421/140-02 Achats pour petits entretiens et réparations de la voirie | Ets Pépinières ABCDE | Matériel pour Pré-Ravel | 34,30
1335 | 425/124-06 Prestations pour entretien des plantations de la voirie | Arbo ABCDE | Abattage d’un orme suivant devis | 742,00
1336 | 72201/125-02 Achats pour entretien de l’Ecole de AAA | AZERTY | Remplacement robinet | 58,00
1337 | 72203/125-02 Achats pour entretien de l’Ecole des Flaches | AZERTY | Système test pour AIB Vinçotte | 51,14
1338 | 875/124-02 Frais de lutte contre les animaux et plantes nuisibles | A.V.D.D. | Enlèvement du cadavre d’un chevreuil | 25,00
1339 | 878/124-02 Frais de fonctionnement des cimetières et des morgues | Plastiques ABCHD | Fournitures pour le cimetière de AAA | 167,92
1340 | 878/124-02 Frais de fonctionnement des cimetières et des morgues | NGFLKDDD | Matériel pour affichage dans les cimetières | 192,63
1341 | 105/123-16 Frais de réception | AZZERTY | Collège des aa et bb/cc/2016 Vins pour les cérémonies à venir | 846,60
1342 | 105/123-16 Frais de réception | Nom enseigne | Collège du aa/bb/2016 Sandwiches pour le 11 novembre | 159,00
1343 | 104/123-02 Fournitures administratives | Quality page | Rouleaux papier pour machine | 3,03
1344 | 104/125-02 Achats pour entretien et fonctionnement de la Maison communale | ABCDE | Nouveau boiler | 267,14
1345 | 421/125-02 Achats pour entretien et fonctionnement pour bâtiment | TTAASSS | Fournitures du hangar | 1.638,81

>>>>> IMAGES <<<<< :

Cette image devrait être affichée dans le document généré, trop large elle est adaptée au document

Une petite image est affichée correctement

Image affichée sans width/height renseignés

Image utilisant un style="float: right;"

Image redimensionnée (plus petite) via les attributs "width=150px" et "height=75px", pas via "style='width:...; height:...;"

Une image redimensionnée dans l'éditeur est rendue redimensionnée et utilise style="height:150px; width:75px"

Image non trouvée externe

Image non trouvée interne

Une image utilisant un chemin de type file:/// ne casse pas la génération

Une image dans un tableau (dans un <p> puis dans le <td>) est correctement rendue

>>>>> CAS SPECIAUX <<<<< :

Balise <pre> :

    Mon texte dans une balise pre

Balise <blockquote> :

> Mon texte dans une balise blockquote

> Mon blockquote contenant ce texte dans un <span> et

> ce texte dans un <p>

Balise <code> utilisée dans du texte :

Mon texte avec du code `dans une balise "code"`

Texte où les caractères accentués comme "à" sont en fait "a" + "`" :

Mon texte, ceci est un vrai "à", ceci n'est pas un vrai "à".

Texte avec un <span> contenant l'espace de début, celui-ci est gardé :

Mon texte puis texte avec espace devant du texte puis texte avec espace devant et du texte puis texte avec espace devant et derrière puis du texte.

Mon texte puis`texte avec espace devant` du texte puis`texte avec espace devant` et du texte puis`texte avec espace devant et derrière` puis du texte.

Texte avec des espaces dans des <em>, les espaces sont souvent perdus avec appy.pod<=0.9.8 :

Texte texte texte texte texte texte.

Texte avec structure complexe plante appy.pod 0.9.7 :

Texte texte texte
- Texte 1 ;
- Texte 2 ;
- Texte 3 ;
- Texte 4.

Texte utilisant la class CSS "mon_style", ne fonctionnait pas en appy<=0.9.8 à cause du "_" (ajouter un style du même nom dans l'ODT pour pouvoir tester) :

Le style devrait être appliqué à ce texte.